Attribute VB_Name = "Program"
' Copyright (c) Traeger Industry Components GmbH.  All Rights Reserved.
Option Explicit

'
' This sample demonstrates how to work with the "PlcValue" class and its subclasses.
'
Public Sub Main()
    ''' ================================================================================
    ''' The PlcValue class itself does represent a value stored in the memory of a PLC
    ''' device that is to be addressed using a specific PLC Address and needs to be
    ''' interpreted using specific PLC Type information.
    ''' ================================================================================

    ''' While the PlcValue class does represent the 'Variant' type of all PLC specific
    ''' value and array types there are different ways to setup a value or an array.

    ' The following example results into a BOOL value at 'DB100.DBX 0.0'.
    Dim booleanValue As PlcBoolean
    Set booleanValue = New_PlcBoolean("DB100.DBX 0.0")

    ' The following example results into a BOOL value at 'DB100.DBX 0.0'
    ' with the inital value specified.
    Set booleanValue = New_PlcBoolean("DB100.DBX 0.0", True)



    ' The following example results into a BYTE value at 'DB100.DBB 0'.
    Dim byteValue As PlcByte
    Set byteValue = New_PlcByte("DB100.DBB 0")

    ' The following exmaple results info a BYTE VALUE at 'DB100.DBB 0'
    ' with the initial value specified.
    Set byteValue = New_PlcByte("DB100.DBB 0", 123)




    ''' While the PlcArray class does represent the 'Variant-Array' type of all PLC
    ''' specific array types there are different ways to setup an array.

    ' The following example results into a ARRAY OF BOOL from
    ' 'DB100.DBX 0.0' - 'DB100.DBX 0.2'.
    ' While the last parameter does define the length of the array.
    Dim booleanArray As PlcBooleanArray
    Set booleanArray = New_PlcBooleanArray("DB100.DBX 0.0", 3)

    ' The following example results into a ARRAY OF BOOL from
    ' 'DB100.DBX 0.0' - 'DB100.DBX 0.4' with the initial values specified.
    ' While the last parameters does define the initial values and length of the array.
    Set booleanArray = New_PlcBooleanArrayUsingValues( _
            "DB100.DBX 0.0", True, False, True, False, True, False, True, False)


    ' The following exmaple results into a ARRAY OF BYTE from
    ' 'DB100.DBB 0' - 'DB100.DBB 2'
    ' While the last parameter does define the length of the array.
    Dim byteArray As PlcByteArray
    Set byteArray = New_PlcByteArray("DB100.DBB 0", 3)

    ' The following example results into a ARRAY OF BYTE from
    ' 'DB100.DBB 0' - 'DB100.DBB 2' with the initial values specified.
    ' While the last parameters does define the initial values and length of the array.
    Set byteArray = New_PlcByteArrayUsingValues( _
            "DB100.DBB 0", 11, 22, 33, 44, 55, 66)

    Dim device As SimaticDevice
    Set device = New_SimaticIPDevice("192.168.0.80")
    
    Dim connection As SimaticDeviceConnection
    Set connection = device.CreateConnection()
    
    Call connection.Open
                
    ' Using the New_PlcValues method we can simple pass a variable number of PlcValue instances at
    ' once to the ReadValues method of the connection to read all the specified values optimized in
    ' speed and traffic. There does also exists a WriteValues method on the connection to write
    ' multiple values also optimized in speed and traffic.
    Dim result() As Variant
    result = connection.ReadValues( _
            New_PlcValues( _
                    booleanValue, _
                    byteValue, _
                    booleanArray, _
                    byteArray))
    
    Call connection.Close
End Sub

